@@ -19,7 +19,7 @@ retry_strategy = Retry(
     allowed_methods=frozenset({'DELETE', 'GET', 'HEAD', 'OPTIONS', 'POST', 'PUT', 'TRACE'})
 )
 adapter = HTTPAdapter(max_retries=retry_strategy)
-DEFAULT_TIMEOUT=20
+DEFAULT_TIMEOUT=5
 http = requests.Session()
 # set the raise_for_status flag to raise exceptions on http status codes other than 200
 http.hooks = {
@@ -147,11 +147,6 @@ class NXGclient:
             input_vcf_id = stage['input_data']['input_vcf_text_id']
             input_data['vcf_download_uri'] = self.base_uri + '/download_vcf/' + input_vcf_id
 
-        # set a pointer to the input sequence fasta uri
-        if 'input_neoepitopes_id' in stage['input_data']:
-            input_neoepitopes_id = stage['input_data']['input_neoepitopes_id']
-            input_data['neoepitopes_download_uri'] = self.base_uri + '/download_neoepitopes/' + input_neoepitopes_id
-            print("neoepitopes_download_uri: " + input_data['neoepitopes_download_uri'])
         #TODO if this is a 'filter' stage, add the input_stage_id information
         # currently, we can't pull this information from the stage endpoint
         if stage['stage_type'] == 'filter':
@@ -222,9 +217,7 @@ def api2cmd_input(tool_group, api_inputs = {}, stage_id = None):
     
     action_map = {
         'mhci': api2cmd_input_mhci,
-        'mhcii': api2cmd_input_mhci,
         'peptide_variant_comparison': api2cmd_input_mhci,
-        'phbr': api2cmd_input_phbr,
         'mutgen': api2cmd_input_mutgen,
         'cluster': api2cmd_input_cluster,
         'pepmatch': api2cmd_input_pepmatch
@@ -234,29 +227,6 @@ def api2cmd_input(tool_group, api_inputs = {}, stage_id = None):
     
     return action_map[tool_group](api_inputs, stage_id)
 
-def api2cmd_input_phbr(api_inputs = {}, stage_id = None):
-    """Given a dict of stage input_data OR a stage_id,
-    return the JSON necessary for the command line tool"""
-
-    if stage_id != None:
-        api_inputs = NXGclient().get_stage_inputs(stage_id)
-
-    api_data = api_inputs['input_parameters']['data']
-
-    # start with the input parameters
-    # NOTE: Here we are assuming only 1 predictor is passed
-    cmd_input = copy.deepcopy(api_data)
-
-    # retrieve the input sequence fasta
-    input_sequence_file = save_file_from_URI(api_inputs['neoepitopes_download_uri'])
-    with open(input_sequence_file, "r") as f:
-        input_fasta_string = f.read()
-
-    # now add the sequence text
-    cmd_input['input_neoepitopes'] = input_fasta_string
-
-    return cmd_input
-
 def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
     """Given a dict of stage input_data OR a stage_id,
     return the JSON necessary for the command line tool"""
@@ -288,9 +258,9 @@ def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
 
     if stage_id != None:
         api_inputs = NXGclient().get_stage_inputs(stage_id)
-
+    
     api_data = api_inputs['input_parameters']['data']
-
+    
     # start with the input parameters
     # NOTE: Here we are assuming only 1 predictor is passed
     cmd_input = copy.deepcopy(api_data)
@@ -302,7 +272,7 @@ def api2cmd_input_pepmatch(api_inputs = {}, stage_id = None):
 
     # now add the sequence text
     cmd_input['input_sequence_text'] = input_fasta_string
-
+    
     return cmd_input
  
 # functions to handle conversion between formats
@@ -354,9 +324,9 @@ def api2cmd_input_cluster(api_inputs = {}, stage_id = None):
         
     if stage_id != None:
         api_inputs = NXGclient().get_stage_inputs(stage_id)
-
+    
     api_data = api_inputs['input_parameters']['data']
-
+    
     # start with the input parameters
     # NOTE: Here we are assuming only 1 predictor is passed
     cmd_input = { 'cluster_pct_identity': api_data['cluster_pct_identity'],
@@ -370,7 +340,7 @@ def api2cmd_input_cluster(api_inputs = {}, stage_id = None):
 
     # now add the sequence text
     cmd_input['input_sequence_text'] = input_fasta_string
-
+    
     return cmd_input       
        
 def api2cmd_input_mutgen(api_inputs = {}, stage_id = None):
@@ -439,9 +409,9 @@ def cmd2api_output_mhci(cmd_output):
     
     for r in api_output['results']:
         
-        # change 'result_type' to 'type' if it is used
-        if 'type' not in r and 'result_type' in r:
-            r['type'] = r.pop('result_type')
+        # change 'result_type' to 'type'
+        r['type'] = r['result_type']
+        del r['result_type']
         
         # skip this result if no table columns are included
         if 'table_columns' not in r:
@@ -450,33 +420,19 @@ def cmd2api_output_mhci(cmd_output):
         # create a new list to hold the table columns with descriptions
         full_table_columns = list()
         
-        column_overrides = {}
-        # pull in the column overrides if they are included in the result
-        if 'column_overrides' in r:
-            column_overrides = copy.deepcopy(r['column_overrides'])
-            # remove column overrides from result object
-            del r['column_overrides']
-        
         # while we go through the table columns, keep track of any
         # row_sort_priority fields so we can renumber staring from
-        # 0 afterwards. The row_sort_priorities dict will be keyed
+        # 0 afterwars. The row_sort_priorities dict will be keyed
         # by the indices of full_table_columns
         row_sort_priorities = dict()
         for c in r['table_columns']:
             c_info = get_column_info(c)
             # make column info unique with other table's same name column
             c_info = c_info.copy()
-            c_info['key'] = c
             if 'row_sort_priority' in c_info:
                 rsp = c_info['row_sort_priority']
                 if rsp is not None:
                     row_sort_priorities[len(full_table_columns)] = rsp
-                    
-            # if an override exists for the column, apply it here
-            if c in column_overrides:
-                for o_field, o_value in column_overrides[c].items():
-                    c_info[o_field] = o_value
-            
             full_table_columns.append(c_info)
         
         # now we need to sort the row_sort_priorities by value,
@@ -509,23 +465,12 @@ def cmd2api_output_mhci(cmd_output):
             # get the fully-qualified field name
             field_name = fqn(f)
             value_limits = dict()
-            # if couldn't find value_limits for given field_name, try with the key of the column_info
-            key = f.pop('key', None)
-            if field_name not in unique_vals and field_name not in field_ranges and key:
-                field_name = key
             if field_name in unique_vals:
                 value_limits['unique_values'] = unique_vals[field_name]
-            # check lowercase version of the field name
-            elif field_name.lower() in unique_vals:
-                value_limits['unique_values'] = unique_vals[field_name.lower()]
 
             if field_name in field_ranges:
                 value_limits['min'] = float(field_ranges[field_name]['min'])
                 value_limits['max'] = float(field_ranges[field_name]['max'])
-            # check lowercase version of the field name
-            elif field_name.lower() in field_ranges:
-                value_limits['min'] = float(field_ranges[field_name.lower()]['min'])
-                value_limits['max'] = float(field_ranges[field_name.lower()]['max'])
             
             if value_limits:
                 f['value_limits'] = value_limits
