@@ -115,31 +115,7 @@ BASE_COLUMN_MAP = {
         "row_sort_priority": 0,
         "default_order": "ascending",
         "number_of_digits": None,
-        "description": "The median percentile rank of binding/elution predictions was calculated by using the adjusted percentiles when available, otherwise the standard percentiles",
-        "hidden": False,
-    },
-    "binding.overall_median_percentile": {
-        "name": "overall_median_percentile",
-        "display_name": "overall median binding percentile",
-        "type": "float",
-        "source": "binding/elution",
-        "sort_order": 1,
-        "row_sort_priority": 3,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The overall median percentile rank for each peptide across methods and alleles was calculated by using the adjusted percentiles when available, otherwise the standard percentiles",
-        "hidden": False,
-    },
-    "binding.global_median_percentile": {
-        "name": "global_median_percentile",
-        "display_name": "global median binding percentile",
-        "type": "float",
-        "source": "binding/elution",
-        "sort_order": 1,
-        "row_sort_priority": 3,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The median of the median binding percentiles by allele for each peptide",
+        "description": "The median percentile rank of binding/elution predictions",
         "hidden": False,
     },
     # binding - method-specific
@@ -151,7 +127,7 @@ BASE_COLUMN_MAP = {
         "type": "float",
         "source": "binding/elution",
         "sort_order": 0,
-        "row_sort_priority": 3,
+        "row_sort_priority": 2,
         "default_order": "descending",
         "number_of_digits": 4,
         "description": "binding/elution prediction score which indicates binding affinity",
@@ -175,24 +151,12 @@ BASE_COLUMN_MAP = {
         "type": "float",
         "source": "binding/elution",
         "sort_order": 1,
-        "row_sort_priority": 3,
+        "row_sort_priority": None,
         "default_order": "ascending",
         "number_of_digits": None,
         "description": "The percentile rank generated by comparing the peptide's IC50/score against those of a set of random peptides from SWISSPROT database",
         "hidden": False,
     },
-    "binding.adjusted_percentile": {
-        "name": "adjusted_percentile",
-        "display_name": "adjusted_percentile",
-        "type": "float",
-        "source": "binding/elution",
-        "sort_order": 1,
-        "row_sort_priority": 3,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The percentile rank adjusted based on the frequency of peptide lengths",
-        "hidden": False,
-    },
     "binding.core": {
         "name": "core",
         "display_name": "core",
@@ -202,7 +166,7 @@ BASE_COLUMN_MAP = {
         "row_sort_priority": None,
         "default_order": None,
         "description": "Always 9 amino acids long sequence. It's a construction used for sequence alignment and identification of binding anchors.",
-        "hidden": False,
+        "hidden": True,
     },
     "binding.icore": {
         "name": "icore",
@@ -213,11 +177,11 @@ BASE_COLUMN_MAP = {
         "row_sort_priority": None,
         "default_order": None,
         "description": "Substring of peptide that encompasses all residues between P1 and P-omega of the MHC.",
-        "hidden": False,
+        "hidden": True,
     },
     # consensus
     "binding.consensus_percentile": {
-        "name": "percentile",
+        "name": "consensus_percentile",
         "display_name": "consensus percentile",
         "type": "float",
         "source": "binding/elution.consensus",
@@ -228,119 +192,6 @@ BASE_COLUMN_MAP = {
         "description": "The median percentile rank of the binding predictions 'ann', 'smm', and 'comblib_sidney2008'",
         "hidden": False,
     },
-    # make the key different for mhcii
-    "binding.consensus_percentile_rank": {
-        "name": "percentile",
-        "display_name": "consensus percentile",
-        "type": "float",
-        "source": "binding/elution.consensus",
-        "sort_order": 2,
-        "row_sort_priority": 1,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The Consensus approach considers a combination of any three of the four methods, if available, where Sturniolo as a final choice.",
-        "hidden": False,
-    },
-    "binding.consensus_adjusted_percentile": {
-        "name": "adjusted_percentile",
-        "display_name": "consensus adjusted percentile",
-        "type": "float",
-        "source": "binding/elution.consensus",
-        "sort_order": 2,
-        "row_sort_priority": 1,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The Consensus approach considers a combination of any three of the four methods, if available, where Sturniolo as a final choice.",
-        "hidden": False,
-    },
-    # mhcii are with mhci
-
-    # mhciinp
-    # these 4 columns are from the mhciinp method only
-    #binding.mhciinp.n_motif 	binding.mhciinp.c_motif 	binding.mhciinp.cleavage_probability_score 	binding.mhciinp.cleavage_probability_percentile_rank 
-    "processing.mhciinp.n_motif": {
-        "name": "n_motif",
-        "display_name": "MHCII-NP N motif",
-        "type": "text",
-        "source": "processing.mhciinp",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "the N-terminus considered for calculating the cleavage probability score",
-        "hidden": False,
-    },
-    "processing.mhciinp.c_motif": {
-        "name": "c_motif",
-        "display_name": "MHCII-NP C motif",
-        "type": "text",
-        "source": "processing.mhciinp",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "the C-terminus considered for calculating the cleavage probability score",
-        "hidden": False,
-    },
-    "processing.mhciinp.cleavage_probability_score": {
-        "name": "cleavage_probability_score",
-        "display_name": "MHCII-NP Cleavage probability score",
-        "type": "float",
-        "source": "processing.mhciinp",
-        "sort_order": 0,
-        "row_sort_priority": 3,
-        "default_order": "descending",
-        "number_of_digits": 4,
-        "description": "The cleavage probability score indicates the probability of the peptide being an MHC II ligand based on three components: (1) the peptide length (2) the N-terminus cleavage motif and (3) the C-terminus cleavage motif. The higher the numerical value of cleavage probability score, the better is the chance of the peptide being a ligand.",
-        "hidden": False,
-    },
-    "processing.mhciinp.cleavage_probability_percentile_rank": {
-        "name": "cleavage_probability_percentile_rank",
-        "display_name": "MHCII-NP Cleavage probability percentile rank",
-        "type": "float",
-        "source": "processing.mhciinp",
-        "sort_order": 1,
-        "row_sort_priority": 3,
-        "default_order": "ascending",
-        "number_of_digits": None,
-        "description": "The predicted cleavage probability score in terms of percentile ranks per the corresponding source protein. The lower the numerical value of the percentile score, the better is the chance of the peptide being a ligand.",
-        "hidden": False,
-    },
-
-    # cd4episcore
-    "immunogenicity.cd4episcore.core": {
-        "name": "cd4episcore_core",
-        "display_name": "CD4episcore core",
-        "type": "text",
-        "source": "immunogenicity.cd4episcore",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "The 9amino acid peptide core used by immunogenicity Neural network model",
-        "hidden": True,
-    },
-    "immunogenicity.cd4episcore.score": {
-        "name": "score",
-        "display_name": "immunogenicity score",
-        "type": "float",
-        "source": "immunogenicity.cd4episcore",
-        "sort_order": 0,
-        "row_sort_priority": 2,
-        "default_order": "descending",
-        "number_of_digits": 5,
-        "description": "'Immunogenicity Score' ranges from 0 to 100, with low values identifying more immunogenic peptides and high values non-immunogenic peptides.",
-        "hidden": False,
-    },
-    "immunogenicity.cd4episcore.combined_score": {
-        "name": "combined_score",
-        "display_name": "immunogenicity Combined Score",
-        "type": "float",
-        "source": "immunogenicity.cd4episcore",
-        "sort_order": 0,
-        "row_sort_priority": 1,
-        "default_order": "descending",
-        "number_of_digits": 5,
-        "description": "the Combined Score is given by combining both HLA binding and the immunogenicity prediction which presumably incorporate the capacity of being recognized by TCR. And low value identifying high capacity of being recognized by TCR.",
-        "hidden": False,
-    },
     # immunogenicity
     "immunogenicity.score": {
         "name": "score",
@@ -354,146 +205,6 @@ BASE_COLUMN_MAP = {
         "description": "Scores greater than 0 indecate a higher probability of being immunogenic than non-immunogenic, while scores less than 0 indicate the opposite.  The greater the distance from 0, the higher the certainty.",
         "hidden": False,
     },
-    # icerfire
-    "icerfire.peptide_a_core": {
-        "name": "peptide_a_core",
-        "display_name": "icerfire peptide_a_core",
-        "type": "text",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "Always 9 amino acids long sequence. It's a construction used for sequence alignment and identification of binding anchors.",
-        "hidden": True,
-    },
-    "icerfire.peptide_b_core": {
-        "name": "peptide_b_core",
-        "display_name": "icerfire peptide_b_core",
-        "type": "text",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "Always 9 amino acids long sequence. It's a construction used for sequence alignment and identification of binding anchors.",
-        "hidden": True,
-    },
-    "icerfire.icore_start_pos": {
-        "name": "icore_start_pos",
-        "display_name": "icerfire icore_start_pos",
-        "type": "int",
-        "source": "icerfire",
-        "sort_order": 1,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "The starting position of the identified ICORE (the submer with the highest MHC binding potential) within the full neopeptide.",
-        "hidden": False,
-    },
-    "icerfire.peptide_a_icore": {
-        "name": "peptide_a_icore",
-        "display_name": "icerfire peptide_a_icore",
-        "type": "text",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "Substring of peptide that encompasses all residues between P1 and P-omega of the MHC.",
-        "hidden": True,
-    },
-    "icerfire.peptide_b_icore": {
-        "name": "peptide_b_icore",
-        "display_name": "icerfire peptide_b_icore",
-        "type": "text",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "description": "Substring of peptide that encompasses all residues between P1 and P-omega of the MHC.",
-        "hidden": True,
-    },
-    "icerfire.peptide_a_el_rank": {
-        "name": "icerfire.peptide_a_el_rank",
-        "display_name": "icerfire peptide_a_el_rank",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 2,
-        "description": "The predicted eluted ligand rank (percentile) of the corresponding wild-type (peptide A) ICORE for the MHC, used to assess how different the mutant is from the self-peptide in terms of binding potential.",
-        "hidden": True,
-    },
-    "icerfire.peptide_b_el_rank": {
-        "name": "icerfire.peptide_b_el_rank",
-        "display_name": "icerfire peptide_b_el_rank",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 2,
-        "description": "The predicted eluted ligand rank (percentile) of the mutated (peptide B) ICORE for the MHC, based on the NetMHCpan EL score. Lower values indicate stronger binding.",
-        "hidden": True,
-    },
-    "icerfire.icore_similarity_score": {
-        "name": "icore_similarity_score",
-        "display_name": "icerfire icore_similarity_score",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 4,
-        "description": "The self-similarity score, representing how similar the mutated ICORE is to its wild-type counterpart. This helps assess self-tolerance, as peptides highly similar to self are less likely to trigger an immune response.",
-        "hidden": True,
-    },
-    "icerfire.icore_blsm_mut_score": {
-        "name": "icore_blsm_mut_score",
-        "display_name": "icerfire icore_blsm_mut_score",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 4,
-        "description": "The BLOSUM substitution matrix score, which quantifies the impact of amino acid mutations in the ICORE compared to the wild-type sequence. A higher score suggests conservative mutations, while a lower score suggests radical changes.",
-        "hidden": True,
-    },
-    "icerfire.total_gene_tpm": {
-        "name": "total_gene_tpm",
-        "display_name": "icerfire total_gene_tpm",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 4,
-        "description": "The expression level of the gene (in transcripts per million, TPM) encoding the neo-epitope, capturing the abundance of the antigen. Highly expressed genes may lead to more frequent presentation of the neo-epitope.",
-        "hidden": False,
-    },
-    "icerfire.prediction": {
-        "name": "prediction",
-        "display_name": "icerfire prediction",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 4,
-        "description": "The final immunogenicity prediction from the ICERFIRE model, indicating whether the neo-epitope is likely to trigger an immune response.",
-        "hidden": False,
-    },
-    "icerfire.%rank": {
-        "name": "percentile_rank",
-        "display_name": "icerfire percentile rank",
-        "type": "float",
-        "source": "icerfire",
-        "sort_order": 3,
-        "row_sort_priority": None,
-        "default_order": None,
-        "number_of_digits": 2,
-        "description": "The percentile rank of the ICERFIRE prediction. A lower percentile rank indicates a higher probability of presentation.",
-        "hidden": False,
-    },
     # netchop
     "processing.netchop.prediction_score": {
         "name": "prediction_score",
@@ -739,16 +450,6 @@ BASE_COLUMN_MAP = {
         "description": "Sum of the MHC and Processing scores",
         "hidden": False,
     },
-    # phbr
-    "phbr.#a":    { "name": "#a", "display_name":"Number of HLA-A alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "Number of HLA-A alleles.", "hidden": True, "display_length": 5 },
-    "phbr.#b":    { "name": "#b", "display_name":"Number of HLA-B alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "Number of HLA-B alleles.", "hidden": True, "display_length": 5 },
-    "phbr.#c":    { "name": "#c", "display_name":"Number of HLA-C alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "Number of HLA-C alleles.", "hidden": True, "display_length": 5 },
-    "phbr.phbr":  { "name": "phbr", "display_name":"PHBR score", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I or class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
-    "phbr.phbr-i":  { "name": "phbr-i", "display_name":"PHBR-I", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I  input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
-    "phbr.phbr-ii":  { "name": "phbr-ii", "display_name":"PHBR-II", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
-    "phbr.phbr-mhci":  { "name": "phbr-i", "display_name":"PHBR-I", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I  input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
-    "phbr.phbr-mhcii":  { "name": "phbr-ii", "display_name":"PHBR-II", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
-
     # pepmatch
     "pepmatch.peptide": {
         "name": "peptide",
@@ -1344,31 +1045,10 @@ binding_methods = [
     "mhcnp",
     "mhcflurry",
 ]
-# add mhcii binding methods
-binding_methods += [
-    "comblib",
-    "consensus",
-    "netmhciipan",
-    "netmhciipan_ba",
-    "netmhciipan_el",
-    "netmhciipan_ba-4.3",
-    "netmhciipan_el-4.3",
-    "netmhciipan_ba-4.2",
-    "netmhciipan_el-4.2",
-    "netmhciipan_ba-4.1",
-    "netmhciipan_el-4.1",
-    "nn_align",
-    "smm_align",
-    "tepitope",
-    "sturniolo",
-]
 
-# define the binding summary columns that do not need to be copied into each method
-# mhciinp has its unique column names so those are added here too
-binding_summary_fields = [
-    "binding.consensus_percentile", "binding.consensus_percentile_rank", "binding.consensus_adjusted_percentile",
-    "processing.mhciinp.n_motif", "processing.mhciinp.c_motif","processing.mhciinp.cleavage_probability_score", "processing.mhciinp.cleavage_probability_percentile_rank",
-]
+# define the binding summary columns that do not need to be copied
+# into each method
+binding_summary_fields = ["binding.median_percentile", "binding.consensus_percentile"]
 
 peptide_variant_comparison_suffixes = ["peptideA", "peptideB", "peptideA_minusB", "peptideB_minusA"]
 
@@ -1390,15 +1070,10 @@ for k, v in BASE_COLUMN_MAP.items():
             # as we don't want to operate on the originals
             v_copy = deepcopy(v)
             v_copy["display_name"] = m + " " + v["display_name"]
-            # add mehtod name to column name
-            v_copy["name"] = f'{m}_{v_copy["name"]}'
-            if m in ["comblib_sidney2008",  "comblib", ] and "score" in k_parts:
+            v_copy["source"] += "." + m
+            if m == "comblib_sidney2008" and "score" in k_parts:
                 v_copy["default_order"] = "ascending"
                 v_copy["number_of_digits"] = 5
-            # do not display method specific median_percentile
-            elif "median_percentile" in k_parts:
-                v_copy["hidden"] = True
-                v_copy["row_sort_priority"] = None
             # update description for mhcnp and mhcflurry
             elif m == "mhcnp":
                 if "score" in k_parts:
@@ -1411,9 +1086,7 @@ for k, v in BASE_COLUMN_MAP.items():
                 elif "percentile" in k_parts:
                     v_copy["description"] = "The percentile rank (ranging from 0 to 100) generated by comparing the peptide's predicted IC50 against those of a set of random peptides from SWISSPROT database.  Lower indicates stronger predicted binding."
             COLUMN_MAP[new_k] = v_copy
-        # add binding.overall_median_percentile and binding.median_percentile
-        if 'percentile' in k:
-            COLUMN_MAP[k] = v
+
     else:
         COLUMN_MAP[k] = v
 
@@ -1457,51 +1130,6 @@ def get_column_info(column_name):
 
     if lower_name in COLUMN_MAP:
         return COLUMN_MAP[lower_name]
-    # adding Percentile Columns for each allele and method
-    elif lower_name.startswith('binding.') and '.percentile.' in lower_name:
-        print("Percentile Column for allele and method was found: " + lower_name)
-        return {
-            "name": lower_name,
-            "display_name": column_name,
-            "type": "float",
-            "source": "binding/elution",
-            "sort_order": 3,
-            "row_sort_priority": None,
-            "default_order": "ascending",
-            "number_of_digits": None,
-            "description": "The percentile rank generated by comparing the peptide's IC50/score against those of a set of random peptides from SWISSPROT database",
-            "hidden": True,
-        }
-    # handle columns like "binding.nn_align.adjusted_percentile.HLA-DRB1*01:01"
-    elif lower_name.startswith('binding.') and '.adjusted_percentile.' in lower_name:
-        print("Adjusted Percentile Column for allele and method was found: " + lower_name)
-        return {
-            "name": lower_name,
-            "display_name": column_name,
-            "type": "float",
-            "source": "binding/elution",
-            "sort_order": 3,
-            "row_sort_priority": None,
-            "default_order": "ascending",
-            "number_of_digits": None,
-            "description": "The adjusted percentile rank generated by comparing the peptide's IC50/score against those of a set of random peptides from SWISSPROT database",
-            "hidden": True,
-        }
-    # handle columns like "binding.median_percentile.HLA-DRB1*01:03"
-    elif lower_name.startswith('binding.median_percentile.'):
-        print("Median Percentile Column for allele was found: " + lower_name)
-        return {
-            "name": lower_name,
-            "display_name": column_name,
-            "type": "float",
-            "source": "binding/elution",
-            "sort_order": 2,
-            "row_sort_priority": None,
-            "default_order": "ascending",
-            "number_of_digits": None,
-            "description": "The median percentile rank of binding/elution predictions by alleles was calculated by using the adjusted percentiles when available, otherwise the standard percentiles",
-            "hidden": True,
-        }
     else:
         # TODO: throw a warning
         print("Warning - Column name not found: " + lower_name)
