@@ -37,7 +37,9 @@
 import os
 import json
 import re
+import numpy as np
 import pandas as pd
+from allele_validator import AlleleValidator
 
 # read in the job description file, which is where we'll pull the output locations from
 # note the '-mod' suffix indicated that I needed to modify the job descriptions file so that the expected
@@ -86,7 +88,7 @@ def get_filter_ranges(table):
 
 def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_consensus=None, keep_empty_row=False):
     job_desc = read_json_file(job_desc_file)
-
+    allele_validator = AlleleValidator()
     all_results = dict()
     warnings = set()
     errors = set()
@@ -95,15 +97,6 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
         # skip over non-prediction jobs
         if j['job_type'] != 'prediction':
             continue
-        # skip over jobs that have no expected outputs
-        if 'expected_outputs' not in j:
-            continue
-        if not j['expected_outputs']:
-            continue
-        # skip over jobs that have expected outputs that do not exist
-        if not all([os.path.exists(o) for o in j['expected_outputs']]):
-            warnings.add("The expected output files for job %s do not all exist. This job will be skipped." % j['job_id'])
-            continue
 
         # loop through the expected outputs of prediction jobs
         for o in j['expected_outputs']:
@@ -163,30 +156,35 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
         final_peptide_table = final_peptide_table.add_prefix('core.')
         # get a list of all binding methods
         binding_methods = list(filter(lambda m: m.startswith('binding.'), all_results['peptide_table'].keys()))
+
         # iterate through the binding methods and join into the final peptide table
         for m in binding_methods:
             #TODO: we're dropping duplicates here, but we need to understand why they are occuring in the first place
             peptide_table = all_results['peptide_table'][m].drop_duplicates()
-            # covert scores, ic50 and percentile to float if they are not
-            for field in ['ic50', 'score', 'percentile',]:
+            # change allele name to iedblabel
+            peptide_table['allele'] = peptide_table['allele'].map(allele_validator.convert_synonym_to_iedblabel)
+            # convert scores, ic50 and percentile to float if they are not
+            for field in ['ic50', 'score', 'percentile', 'adjusted_percentile']:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
-            join_cols = ['peptide']
-            # if allele is in both tables, we need to join on it
-            if 'allele' in peptide_table and 'core.' + 'allele' in final_peptide_table:
-                join_cols.append('allele')
+            join_cols = ['peptide', 'allele']
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
+            ignored_cols = ['seq_num', 'start', 'end', 'peptide_length']
+            ignored_join_cols = right_join_cols + [m + '.' + x for x in ignored_cols]
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
             left_on=left_join_cols,
             right_on=right_join_cols,
-            how='left').drop(labels=right_join_cols, axis=1)
+            how='left').drop(labels=ignored_join_cols, axis=1)
 
         # add the median binding percentile column before the first binding-related column
         #TODO: discuss if we need median column if there's only 1 binding method
         if binding_methods:
+            # calculate median by using the adjusted percentiles when available, otherwise the standard percentiles
             binding_columns = list(filter(lambda m: m.startswith('binding.'), final_peptide_table.columns))
-            percentile_columns = list(filter(lambda m: m.startswith('binding.') and m.endswith('.percentile'), final_peptide_table.columns))
+            percentile_columns = [col for col in final_peptide_table.columns if col.startswith('binding.') and col.endswith('.percentile')]
+            adjusted_percentile_columns = {col.replace('.adjusted_percentile', ''): col for col in final_peptide_table.columns if col.startswith('binding.') and col.endswith('.adjusted_percentile')}
+            percentile_columns = [adjusted_percentile_columns.get(col.replace('.percentile', ''), col) for col in percentile_columns]
             first_binding_column_index = list(final_peptide_table.columns).index(binding_columns[0])
             final_peptide_table.insert(first_binding_column_index,
                                     'binding.median_percentile',
@@ -196,34 +194,82 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
             #TODO: we need a flag for whether the consensus method was selected
             # read the flag in job_desciption file if it's not given
             if has_consensus:
-                all_consensus_percentile_columns = ['binding.ann.percentile', 'binding.comblib_sidney2008.percentile', 'binding.smm.percentile']
+                all_consensus_percentile_columns = [
+                    'binding.comblib.percentile',
+                    'binding.nn_align.percentile',
+                    'binding.smm_align.percentile',
+                    'binding.tepitope.percentile',
+                ]
+                # Determine the consensus percentile columns present in the table
                 consensus_percentile_columns = set(all_consensus_percentile_columns) & set(final_peptide_table.columns)
-                if consensus_percentile_columns:
-                    median_index = list(final_peptide_table.columns).index('binding.median_percentile')
-                    final_peptide_table.insert(median_index + 1,
-                                            'binding.consensus_percentile',
-                                            final_peptide_table.filter(items=consensus_percentile_columns).median(axis=1).round(2))
 
-        # add the immunogenicity data
-        if 'immunogenicity' in all_results['peptide_table']:
-            print("found immunogenicity")
-            m = 'immunogenicity'
+                if consensus_percentile_columns:
+                    # Define column groups based on the presence of 'binding.comblib.percentile'
+                    condition_1_columns = [
+                        col for col in ['binding.comblib.percentile', 'binding.nn_align.percentile', 'binding.smm_align.percentile']
+                        if col in final_peptide_table.columns
+                    ]
+                    condition_2_columns = [
+                        col for col in ['binding.nn_align.percentile', 'binding.smm_align.percentile', 'binding.tepitope.percentile']
+                        if col in final_peptide_table.columns
+                    ]
+
+                    # Determine which condition to use for each row
+                    def calculate_consensus_percentile(row):
+                        if not pd.isna(row.get('binding.comblib.percentile', np.nan)):
+                            return row.filter(items=condition_1_columns).median().round(2)
+                        else:
+                            return row.filter(items=condition_2_columns).median().round(2)
+
+                    # Define column groups based on the presence of 'binding.comblib.percentile'
+                    condition_1_adjusted_columns = [
+                        col for col in ['binding.comblib.adjusted_percentile', 'binding.nn_align.adjusted_percentile', 'binding.smm_align.adjusted_percentile']
+                        if col in final_peptide_table.columns
+                    ]
+                    condition_2_adjusted_columns = [
+                        col for col in ['binding.nn_align.adjusted_percentile', 'binding.smm_align.adjusted_percentile', 'binding.tepitope.adjusted_percentile']
+                        if col in final_peptide_table.columns
+                    ]
+
+                    # Determine which condition to use for each row
+                    def calculate_consensus_adjusted_percentile(row):
+                        if not pd.isna(row.get('binding.comblib.adjusted_percentile', np.nan)):
+                            return row.filter(items=condition_1_adjusted_columns).median().round(2)
+                        else:
+                            return row.filter(items=condition_2_adjusted_columns).median().round(2)
+
+                    # find the index for median column
+                    median_index = list(final_peptide_table.columns).index('binding.median_percentile')
+                    final_peptide_table.insert(
+                        median_index + 1,
+                        'binding.consensus_adjusted_percentile',
+                        final_peptide_table.apply(calculate_consensus_adjusted_percentile, axis=1)
+                    )
+                    final_peptide_table.insert(
+                        median_index + 1,
+                        'binding.consensus_percentile_rank',
+                        final_peptide_table.apply(calculate_consensus_percentile, axis=1)
+                    )
+
+        # add the immunogenicity (cd4episcore) data
+        if 'immunogenicity.cd4episcore' in all_results['peptide_table']:
+            print("found immunogenicity.cd4episcore")
+            m = 'immunogenicity.cd4episcore'
             #TODO: we're dropping duplicates here, but we need to understand why they are occuring in the first place
             peptide_table = all_results['peptide_table'][m].drop_duplicates()
             # covert scores to float if it is not
             for field in ['score', ]:
                 if peptide_table.get(field, None) is not None:
                     peptide_table[field] = peptide_table[field].astype('float64')
-            join_cols = ['peptide']
-            # if allele is in both tables, we need to join on it
-            if 'allele' in peptide_table and 'core.' + 'allele' in final_peptide_table:
-                join_cols.append('allele')
+            join_cols = ['peptide', ]
             left_join_cols = ['core.' + x for x in join_cols]
             right_join_cols = [m + '.' + x for x in join_cols]
+            ignored_cols = ['seq_num', 'start', 'end', 'peptide_length']
+            ignored_join_cols = right_join_cols + [m + '.' + x for x in ignored_cols]
             final_peptide_table = pd.merge(final_peptide_table, peptide_table.add_prefix(m + '.'),
             left_on=left_join_cols,
             right_on=right_join_cols,
-            how='left').drop(labels=right_join_cols, axis=1)
+            how='left').drop(labels=ignored_join_cols, axis=1)
 
         # add the basic processing & netctlpan data
         peptide_processing_methods = ['processing.basic_processing', 'processing.netctl', 'processing.netctlpan']
@@ -248,6 +294,63 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
 
         merged_results['peptide_table'] = final_peptide_table
 
+    # Create Pivot Table from peptide_table
+    if 'peptide_table' in merged_results and 'binding.median_percentile' in merged_results['peptide_table'].columns:
+
+        # Dynamically identify all method-related columns
+        # method_columns = [col for col in merged_results['peptide_table'].columns if col.startswith('binding.')]
+
+        # binding.median_percentile in the merged_results['peptide_table'] is the median percenile by allele for each peptide
+        # create pivot table on peptide that inludes the median percentiles by allele
+
+        print(merged_results['peptide_table'].to_csv())
+        # Pivot the original DataFrame to spread method-allele combinations as columns
+        pivot_df =  merged_results['peptide_table'].pivot_table(index='core.peptide', 
+                                columns='core.allele', 
+                                values='binding.median_percentile', 
+                                aggfunc='mean')
+
+        # Rename the allele columns to allele_'median_percentile'
+        pivot_df.columns = ["binding.median_percentile."+c for c in pivot_df.columns if c != 'peptide']
+
+        # Calculate the median of the median percentiles
+        pivot_df['binding.global_median_percentile'] = pivot_df.median(axis=1)
+
+        # Reset the index of pivot_df to bring 'core.peptide' back as a column
+        #pivot_df = pivot_df.reset_index()
+
+        # Concatenate all results
+        # Finding the adjusted percentiles when available, otherwise using the standard percentiles.
+        # This section identifies columns that end with '.percentile' and replaces them with their corresponding
+        # '.adjusted_percentile' columns if they exist. This ensures that we use the adjusted percentiles for calculations
+        # when they are available, providing more accurate results.
+        percentile_columns = [col for col in merged_results['peptide_table'].columns if col.endswith('.percentile')]
+        adjusted_percentile_columns = {col.replace('.adjusted_percentile', ''): col for col in merged_results['peptide_table'].columns if col.endswith('.adjusted_percentile')}
+        percentile_columns = [adjusted_percentile_columns.get(col.replace('.percentile', ''), col) for col in percentile_columns]
+        # remove 'binding.consensus_percentile_rank' and 'binding.consensus_adjusted_percentile' from percentile_columns
+        percentile_columns = [col for col in percentile_columns if col not in ['binding.consensus_percentile_rank', 'binding.consensus_adjusted_percentile']]
+        # create table with all percentiles
+        all_percentile_pivot_df = merged_results['peptide_table'].pivot(index='core.peptide', columns='core.allele', values=percentile_columns)
+
+        # Flatten the MultiIndex columns to have unique names
+        all_percentile_pivot_df.columns = ['.'.join(col).strip() for col in all_percentile_pivot_df.columns.values]
+
+        # Calculate the median of the median percentiles
+        all_percentile_pivot_df['binding.overall_median_percentile'] = all_percentile_pivot_df.median(axis=1)
+        # Concatenate all results
+        pivot_df = pd.merge(all_percentile_pivot_df, pivot_df, on='core.peptide', how='inner').reset_index()
+
+        # Select only the 'peptide' and 'median median percentile' columns from result_df
+        subset_pivot_df = pivot_df[['core.peptide', 'binding.global_median_percentile']].drop_duplicates()
+
+        # Merge the selected columns back to the original df on 'peptide'
+        merged_results['peptide_table'] = pd.merge(merged_results['peptide_table'], subset_pivot_df, on='core.peptide', how='left')
+
+        # Print result
+        #print(final_peptide_table)
+        # print(pivot_df.to_csv())
+        merged_results['consolidated_peptide_table'] = pivot_df
+
     # Merge the residue tables. A netchop is the only table that outputs one currently, this isn't necessary, but we have the logic worked out - and UNTESTED.
     # now let's merge the reidue tables
     if 'residue_table' in all_results:
@@ -288,7 +391,7 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
     final_results = list()
     for t in merged_results.keys():
         # drop all na and all "-" columns
-        if t in ['peptide_table', 'residue_table']:
+        if t in ['peptide_table', 'residue_table', 'consolidated_peptide_table']:
             df_t = (merged_results[t].fillna('-') == '-').all()
             empty_columns = df_t[df_t]
             if not empty_columns.empty:
@@ -302,13 +405,26 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
                 mask = merged_results[t][columns_to_check].apply(lambda row: all(pd.isna(val) or val == '-' for val in row), axis=1)
                 # Drop rows where the mask is True
                 merged_results[t] = merged_results[t][mask == False].reset_index(drop=True)
+            if t =='peptide_table':
+                if all(col in merged_results['peptide_table'].columns for col in ['immunogenicity.cd4episcore.score', 'binding.global_median_percentile']):
+                    a = 0.4
+                    a1 = 1 - a
+                    merged_results['peptide_table']['immunogenicity.cd4episcore.combined_score'] = round((a * merged_results['peptide_table']['immunogenicity.cd4episcore.score']) + (a1 * merged_results['peptide_table']['binding.global_median_percentile']), 5)
+                    # add cd4episcore.combined_score and cd4episcore.score to pivot table
+                    subset_peptide_table = merged_results['peptide_table'][['core.peptide', 'immunogenicity.cd4episcore.score', 'immunogenicity.cd4episcore.combined_score']]
+                    subset_peptide_table = subset_peptide_table.drop_duplicates()
+                    merged_results['consolidated_peptide_table'] = pd.merge( merged_results['consolidated_peptide_table'], subset_peptide_table, on='core.peptide', how='left')
+                # if we would like to drop column 'binding.global_median_percentile'
+                merged_results['peptide_table'] = merged_results['peptide_table'].drop(columns=['binding.global_median_percentile'], errors='ignore')
 
         # get unique_vals for string type columns, and field_ranges for number type for each table
         unique_vals, field_ranges, filter_warnings = get_filter_ranges(merged_results[t])
         warnings.update(filter_warnings)
+        column_overrides = {}
         # replace na with "-" after get filter information (e.g. min, max)
-        if t in ['peptide_table', 'residue_table']:
+        if t in ['peptide_table', 'residue_table', 'consolidated_peptide_table']:
             merged_results[t] = merged_results[t].fillna('-')
+            column_overrides = get_column_overrides(merged_results[t])
         dict_result = merged_results[t].to_dict(orient='split')
         del dict_result['index']
         dict_result['result_type'] = t
@@ -316,6 +432,7 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
         dict_result['table_data'] = sorted(dict_result.pop('data'))
         dict_result['unique_vals'] = unique_vals
         dict_result['field_ranges'] = field_ranges
+        dict_result['column_overrides'] = column_overrides
         final_results.append(dict_result)
 
     # add the processing plots onto the results
@@ -335,9 +452,35 @@ def aggregate_result_file(job_desc_file, output_dir, aggregate_output_dir, has_c
     # That's it!  The above object can now be dumped to JSON.
 
     # save result to output path
-    # print('aggregated_results: %s' % aggregated_results)
+    #print('aggregated_results: %s' % aggregated_results)
     final_result_file_path = os.path.join(aggregate_output_dir, 'aggregated_result.json')
     save_json(aggregated_results, final_result_file_path)
     print('aggregated_result_path:%s' % final_result_file_path)
 
     return
+
+def get_column_overrides(table):
+    # The iput df table has columns like "binding.smm_align.percentile", "binding.nn_align.percentile", "binding.smm_align.adjusted_percentile","binding.nn_align.adjusted_percentile". 
+    # This function identifies columns with the same prefix where the values in "percentile" and "adjusted_percentile" columns are equal across all rows.
+    # It returns a dictionary of these column names to be used for column overrides.
+    # Then add those column names to column_overrides
+    # Identify columns with the same prefix
+    column_overrides = {}
+    prefix_columns = {}
+    for col in table.columns:
+        prefix = col.rsplit('.', 1)[0]
+        if prefix not in prefix_columns:
+            prefix_columns[prefix] = []
+        prefix_columns[prefix].append(col)
+
+    # Check if values in "percentile" and "adjusted_percentile" columns are equal across all rows
+    for prefix, cols in prefix_columns.items():
+        if len(cols) > 1:
+            percentile_col = f"{prefix}.percentile"
+            adjusted_percentile_col = f"{prefix}.adjusted_percentile"
+            if percentile_col in cols and adjusted_percentile_col in cols:
+                if table[percentile_col].equals(table[adjusted_percentile_col]):
+                    # mark the adjusted_percentile_col hidden
+                    column_overrides[adjusted_percentile_col] = { "hidden": True }
+
+    return column_overrides
